// Namespace for utility functions
var utils = {};

utils.is_touch_enabled = function () {"use strict"
  return ( 'ontouchstart' in window ) ||
    ( navigator.maxTouchPoints > 0 ) ||
    ( navigator.msMaxTouchPoints > 0 );
}

utils.setCookie = function (cookieName,cookieValue,nDays) {"use strict";
  var today = new Date();
  var expire = new Date();
  if (nDays==null || nDays==0) nDays=1;
  expire.setTime(today.getTime() + 60000*60*24*nDays);
  document.cookie = cookieName+"="+escape(cookieValue) + ";expires="+expire.toGMTString();
  //console.log(expire.toGMTString());
}

utils.getCookie = function (cookieName) {"use strict";
  var theCookie=" "+document.cookie;
  var ind=theCookie.indexOf(" "+cookieName+"=");
  if (ind==-1) ind=theCookie.indexOf(";"+cookieName+"=");
  if (ind==-1 || cookieName=="") return "";
  var ind1=theCookie.indexOf(";",ind+1);
  if (ind1==-1) ind1=theCookie.length;
  return decodeURIComponent(theCookie.substring(ind+cookieName.length+2,ind1));
}

// Namespace for intro functions
var intro = {};

intro.runIntro = function () {"use strict";

  if( utils.is_touch_enabled() || utils.getCookie('skipIntro') || true ){
    document.documentElement.classList.remove('intro');
  } else {
    intro = document.getElementById("intro");
    if(XMLHttpRequest) var x = new XMLHttpRequest();
    else var x = new ActiveXObject("Microsoft.XMLHTTP");
    x.open("GET", "./_inc/intro.php", true);
    x.send();
    x.onreadystatechange = function(){
      if(x.readyState == 4){
        if(x.status == 200){
          intro.innerHTML = x.responseText;
          const video = document.querySelector('#intro video');
          video.onended = (event) => {
            document.documentElement.classList.remove('intro');
            //console.log('Video stopped either because 1) it was over, or 2) no further data is available.');
          };
          utils.setCookie('skipIntro', 'true', 7);
        } else {
          intro.innerHTML = "Error loading document";
        }
      }
    }
  }
}

// Namespace for keyart functions
var keyart = {};

keyart.kids = document.getElementById("kids");

keyart.loadKids = function () {"use strict";
  function loadKids(){
    keyart.kids.innerHTML = '<div id="kid1" class="w100 kid"></div><div id="kid2" class="w100 kid"></div><div id="kid3" class="w100 kid"></div><div id="kid4" class="w100 kid"></div>';
    //keyart.kids();
    setTimeout(function(){
      keyart.setObserver();
      //console.log('setObserver called');
    },500);
    //console.log('kids loaded');
    window.removeEventListener("scroll", loadKids, { passive: true });
  }
  window.addEventListener("scroll", loadKids, { passive: true });
  //console.log('scroll listener added');
}

keyart.setObserver = function () {"use strict";
  // console.log('setObserver')
  let options = {
    rootMargin: '0px',
    threshold: 1
  }
  const intersectionCallback = (entries, observer) => {
    entries.forEach(entry => {
      // you can find out easily if target is intersecting by inspecting `isIntersecting` property
      if (entry.isIntersecting) {
        var kids = document.querySelectorAll('.kid');
        for (var i = 0; i < kids.length; i++) {
            kids[i].classList.add('animate');
        }
        //console.log('kids animating');
      } else {
        var kids = document.querySelectorAll('.kid');
        for (var i = 0; i < kids.length; i++) {
            kids[i].classList.remove('animate');
        }
      }
    });
  }
  let observer = new IntersectionObserver(intersectionCallback, options);
  let target = document.querySelector('#trigger');
  observer.observe(target);
}

keyart.animateKids = function () {"use strict";
  //console.log('animate kids');
  var kids = document.querySelectorAll('.kid');
  for (var i = 0; i < kids.length; i++) {
      kids[i].classList.add('intersect');
  }
}

//Namespace for team functions
var team = {};

team.bioindex = 0;
team.bios = [];
team.pageIndex = 0;
team.pages = 3;

team.loadBios = function (page) {"use strict";
  // Reac Cast & Creative Bios into array
  var request = new XMLHttpRequest();

  request.open('GET', page, true);
  
  request.onload = function() {
    if (request.status >= 200 && request.status < 400) {
      var resp = request.responseText;
      var el = document.createElement( 'html' );
      el.innerHTML = resp;
      // Get all members as a NodeList
      var members = el.querySelectorAll('.member');
      // Convert members NodeList to an array
      //console.log(members.length);
      team.bios = Array.from(members);
      //console.log(team.bios);
    }
  };
  request.send();

  const overlayInner = document.querySelector('#overlay-inner');
  const castMain = document.querySelector('#cast');
  const castLinks = document.querySelector('#cast-links');
  const teamMain = document.querySelector('#team');

  ['click','touchstart'].forEach( function(e) {
    document.addEventListener(e, function(e){
      if( e.target.classList.contains('next') ) {
        // OVERLAY NEXT
        team.bioIndex++;
        overlayInner.classList.remove('show');
        setTimeout(function(){
          overlayInner.innerHTML = team.bios[team.bioIndex].outerHTML;
          //overlayInner.querySelector('.headshot').classList.add('open');
          overlayInner.classList.add('show');
        },100);
        /*setTimeout(function(){
          overlayInner.querySelector('.headshot').classList.remove('open');
        },1200);*/
      } else if(e.target.classList.contains('prev')) {
        // OVERLAY PREV
        team.bioIndex--;
        overlayInner.classList.remove('show');
        setTimeout(function(){
          overlayInner.innerHTML = team.bios[team.bioIndex].outerHTML;
          //overlayInner.querySelector('.headshot').classList.add('open');
          overlayInner.classList.add('show');
        },100);
        /*setTimeout(function(){
          overlayInner.querySelector('.headshot').classList.remove('open');
        },1200);*/
      } else if(e.target.classList.contains('close')) {
        // OVERLAY CLOSE
        overlayInner.classList.remove('show');
        document.documentElement.classList.remove('overlay-open');
      } else if(e.target.classList.contains('member')) {
        // CAST/CREATIVE MEMBER
        var child = e.target;
        var parent = child.parentNode;
        var index = Array.prototype.indexOf.call(parent.children, child);
        if(e.target.classList.contains('creative-link')) {
          index = index + document.querySelectorAll("#cast-links a").length;
        }
        team.bioIndex = index;
        //console.log(team.bioIndex);
        document.documentElement.classList.add('overlay-open');
        
        setTimeout(function(){
          overlayInner.innerHTML = team.bios[team.bioIndex].outerHTML;
          //overlayInner.querySelector('.headshot').classList.add('open');
          overlayInner.classList.add('show');
        },100);
        /*setTimeout(function(){
          overlayInner.querySelector('.headshot').classList.remove('open');
        },1200);*/
      } else if( e.target.classList.contains('cast-next') ) {
        // CAST JARS NEXT
        castMain.classList.remove('page'+team.pageIndex);
        team.pageIndex++;
        castMain.classList.add('page'+team.pageIndex);
      } else if(e.target.classList.contains('cast-prev')) {
        // CAST JARS PREV
        castMain.classList.remove('page'+team.pageIndex);
        team.pageIndex--;
        castMain.classList.add('page'+team.pageIndex);
      } else if( e.target.classList.contains('team-cast') ) {
        // MAIN CAST LINK
        e.preventDefault();
        if(!teamMain.classList.contains('cast')){
          teamMain.classList.remove('creative');
          teamMain.classList.add('cast');
          castMain.classList.remove('page'+team.pageIndex);
          team.pageIndex=0;
          castMain.classList.add('page'+team.pageIndex);
          setTimeout(function(){
            castMain.classList.add('flicker');
          },600);
          setTimeout(function(){
            castMain.classList.remove('flicker');
            castMain.classList.add('flicker2');
          },650);
          setTimeout(function(){
            castMain.classList.remove('flicker2');
            castMain.classList.add('flicker');
          },1100);
          setTimeout(function(){
            castMain.classList.remove('flicker');
            castMain.classList.add('flicker2');
          },1150);
          setTimeout(function(){
            castMain.classList.remove('flicker2');
            castMain.classList.remove('page'+team.pageIndex);
            team.pageIndex=1;
            castMain.classList.add('page'+team.pageIndex);
          },50);
        }
      } else if(e.target.classList.contains('team-creative')) {
        // MAIN CREATIVE LINK
        e.preventDefault();
        if(!teamMain.classList.contains('creative')){
          teamMain.classList.remove('cast');
          teamMain.classList.add('creative');
        }
        if($(window).width() > 767) {
          playVideo();
        }
      } else {
        
      }

      if(team.bioIndex == (team.bios.length - 1) ){
        document.querySelector('#overlay .next').style.display = 'none';
      } else {
        document.querySelector('#overlay .next').style.display = 'block';
      }

      if(team.bioIndex == 0 ){
        document.querySelector('#overlay .prev').style.display = 'none';
      } else {
        document.querySelector('#overlay .prev').style.display = 'block';
      }

      //console.log(e.target.classList);

    }, false);
  });

  //console.log($(window).width());

  function playVideo() {
    var theVideo = document.querySelector('#creative-team-video');        theVideo.pause();
    theVideo.currentTime = 0;
    theVideo.play();
    document.getElementById('creative-links').classList.add('inactive');
    const linkTimeout = setTimeout(function(){
      document.getElementById('creative-links').classList.remove('inactive');
      clearTimeout(linkTimeout);
    },3500);
    const thisTimeout = setTimeout(function(){
      if(teamMain.classList.contains('creative') && ($(window).width() > 767)){
        playVideo();
        document.getElementById('creative-links').classList.add('inactive');
      } else {
        clearTimeout(thisTimeout);
      }
    },15000);
  }

  ['mouseover'].forEach( function(e) {
    document.addEventListener(e, function(e){
      if( e.target.classList.contains('cast-link') ) {
        var child = e.target;
        var parent = child.parentNode;
        var index = Array.prototype.indexOf.call(parent.children, child) + 1;
        //console.log(index);
        document.querySelector('#jars-over div:nth-child('+index+')').classList.add('active');
      }
    }, false);
  });

  ['mouseout'].forEach( function(e) {
    document.addEventListener(e, function(e){
      if( e.target.classList.contains('cast-link') ) {
        var child = e.target;
        var parent = child.parentNode;
        var index = Array.prototype.indexOf.call(parent.children, child) + 1;
        document.querySelector('#jars-over div:nth-child('+index+')').classList.remove('active');
      }
    }, false);
  });
};

function debounce(func){
  var timer;
  return function(event){
    if(timer) clearTimeout(timer);
    timer = setTimeout(func,1000,event);
  };
}

window.addEventListener("resize",debounce(function(e){
  //alert("end of resizing");
  //alert($(window).width() > 767);
  if ($(window).width() > 767) {
    document.querySelector('#cast').classList.remove('page'+team.pageIndex);
    team.pageIndex = 1;
    document.querySelector('#cast').classList.add('page'+team.pageIndex);
  }
}));

window.addEventListener('load', () => {
  document.documentElement.classList.add('page-loaded');
console.log('test');
  // code here
  team.loadBios('cast.html');
  intro.runIntro();
  keyart.loadKids();

 /*
     function fireModal() {
       $("#popup").show();
       $("#popup-bg").show();
     }
 
   /*  setTimeout(function() {
       fireModal();
     }, 1000); *
 
     $(document).on( "click",".close-popup", function(e) {
       e.preventDefault();
       $("#popup").fadeOut();
       $("#popup-bg").fadeOut();
     });
 
     $(document).on( "click","#popup-bg", function(e) {
       e.preventDefault();
       $("#popup").fadeOut();
       $("#popup-bg").fadeOut();
     });*/


});