//list dependencies

const { src, dest, watch, series } = require('gulp');
const prefix = require('gulp-autoprefixer');
const minify = require('gulp-clean-css');
const terser = require('gulp-terser');
const imagemin = import('imagemin');
const mozjpeg = import('imagemin-mozjpeg');
const imagewebp = require('gulp-webp');

// create functions

// scss
function compilescss(){
  const sass = require('gulp-sass')(require('node-sass'));
  return src('_src/scss/*.scss')
   .pipe(sass())
   .pipe(prefix())
   .pipe(minify())
   .pipe(dest('_dist/css'))
}

// js
function jsmin(){
  return src('_src/js/*.js')
  .pipe(terser())
  .pipe(dest('_dist/js'))
}

// images
function optimizeimg(){
  return src('_src/img/*.+(jpg|png)')
  .pipe(imagemin([
    mozjpeg({ quality:60, progressive: true }),
    optipng({ optimizationLevel: 2 })
  ]))
  .pipe(dest('_dist/img'))
}

// webp images
function webpImage(){
  return src('_dist/img/*.+(jpg|png)')
  .pipe(imagewebp())
  .pipe(dest('_dist/img'))
}

// create watchlist
function watchTask() {
  watch('_src/scss/*.scss', compilescss);
  watch('_src/js/*.js', jsmin);
  watch('_src/img/*.(jpg,png)', optimizeimg);
  watch('_dist/src/img/*.(jpg,png)', webpImage);
}

// default gulp
exports.default = series(
  compilescss,
  jsmin,
  optimizeimg,
  webpImage,
  watchTask
)